import math
import unittest

import ramda as R

"""
https://github.com/ramda/ramda/blob/master/test/divide.js
"""


class TestDivide(unittest.TestCase):
  def test_divides_two_numbers(self):
    self.assertEqual(4, R.divide(28, 7))


if __name__ == '__main__':
  unittest.main()



from .private._curry2 import _curry2
from .private._isString import _isString


def inner_nth(offset, arr):
  idx = len(arr) + offset if offset < 0 else offset
  if _isString(arr):
    return arr[idx] if idx < len(arr) and idx >= 0 else ''
  else:
    return arr[idx] if idx < len(arr) and idx >= 0 else None


nth = _curry2(inner_nth)



import copy


def _clone(value, deep=True):
  """
  Unless there is no problem, we will use the built-in copy module.
  """
  if deep:
    return copy.deepcopy(value)
  else:
    return copy.copy(value)



from .private._curry2 import _curry2

"""
Since in JavaScript we can represent key-value as object,
but in Python, we can't.
So we treat objOf only works for dict in Python.
But for the naming convention, we keep the name of objOf.
"""
objOf = _curry2(lambda key, val: {key: val})



from math import isnan

import ramda as R

from ._isNumber import _isNumber


class _Set(set):
  def add(self, item):
    if R.filter(R.equals(item), list(self.__iter__())):
      return False
    else:
      super().add(item)
      return True



from ._helper import getAttribute


def _reduced(x):
  if getAttribute(x, '@@transducer/reduced'):
    return x
  else:
    return {
        '@@transducer/value': x,
        '@@transducer/reduced': True
    }
